<?php

// SESSION

function sessionStart () {
  global $conf;
  session_name($conf['session_name']);
  
  session_set_cookie_params(time()+$conf['session_lifetime']);
  if(session_start()){
    return session_id();
  }
  else{
    return 0;
  }
}

// CONNECT

function dbConnect () {
  global $conf_db;
  
  $db_options = array(
                          PDO::ATTR_PERSISTENT          => true,
                          PDO::MYSQL_ATTR_INIT_COMMAND  => "SET NAMES 'UTF8'"
                    );
                 
  try {
      $db_connect = new PDO("mysql:host=".$conf_db['db_server'].";dbname=".$conf_db['db_name'], $conf_db['db_user'], $conf_db['db_passwd'], $db_options);
      $db_connect->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
      return $db_connect;
  } catch (PDOException $e) {
      logIt ('mysql', $e->getMessage().' -- '.$e->getFile());
      return 0;
  }
}

// QUERY FORGE

function addQuery ($table_name, $field_data) {
  $fields = '';
  $values = '';
  $c      = 0;
  foreach($field_data as $field_name => $field_value) {
    if($c != 0){$glue = ", ";}else{$glue = '';}
    $fields .= $glue."`".$field_name."`";
    if($field_value == 'NULL'){
      $values .= $glue.$field_value;
    }
    else{
      $values .= $glue."'".$field_value."'";
    }
    $c++;
  }
  $query = "INSERT INTO $table_name ($fields) VALUES ($values);";
  return $query;
}

function editQuery ($table_name, $field_data, $data_id = 0) {
  $set   = '';
  $c     = 0;
  foreach($field_data as $field_name => $field_value){
    if($c != 0){$glue = ", ";}else{$glue = '';}
    
    if($field_value == 'NULL'){
      $set .= $glue."`".$field_name."`"." = ".$field_value;
    }
    else{
      $set .= $glue."`".$field_name."`"." = '".$field_value."'";
    }
    $c++;
  }
  $query = "UPDATE $table_name SET $set WHERE id = '$data_id' LIMIT 1;";
  return $query;
}

function deleteQuery ($table_name, $data_id) {
  $query = "DELETE FROM $table_name WHERE id = '$data_id' LIMIT 1;";
  return $query;
}

function selectQuery ($table_name, $data_id) {
  $query = "SELECT * FROM $table_name WHERE id = '$data_id' LIMIT 1;";
  return $query;
}

function selectAllQuery ($table_name, $order_by = 'id', $order = 'ASC') {
  if($order_by == 'name'){$order_by = "LOWER($order_by)";}
  $query = "SELECT * FROM $table_name ORDER BY $order_by $order;";
  return $query;
}

// EXEC QUERY

function execAdd ($query) {
  global $db_connect;
  try {
    $result = $db_connect->exec($query);
    $last_id = $db_connect->lastInsertId();
    return $last_id;
  }
  catch (PDOException $e) {
    logIt ('mysql', $e->getMessage().' -- '.$e->getFile().' -- '.$query);
    return 0;
  }
}

function execEdit ($query) {
  global $db_connect;
  try {
    $result = $db_connect->exec($query);
    return $result;
  }
  catch (PDOException $e) {
    logIt ('mysql', $e->getMessage().' -- '.$e->getFile().' -- '.$query);
    return 0;
  }
}

function execDelete ($query) {
  global $db_connect;
  try {
    $result = $db_connect->exec($query);
    return $result;
  }
  catch (PDOException $e) {
    logIt ('mysql', $e->getMessage().' -- '.$e->getFile().' -- '.$query);
    return 0;
  }
}

function execSelect ($query) {
  global $db_connect;
  try {
    $result = $db_connect->query($query)->fetch(PDO::FETCH_ASSOC);
    return $result;
  }
  catch (PDOException $e) {
    logIt ('mysql', $e->getMessage().' -- '.$e->getFile().' -- '.$query);
    return array();
  }
}

function execSelectAll ($query) {
  global $db_connect;
  try {
    $results = $db_connect->query($query)->fetchAll(PDO::FETCH_ASSOC);
    return $results;
  }
  catch (PDOException $e) {
    logIt ('mysql', $e->getMessage().' -- '.$e->getFile().' -- '.$query);
    return array();
  }
}

// GENERIC DATA HANDLING

function select ($table_name, $data_id) {
  $query  = selectQuery ($table_name, $data_id);
  $result = execSelect ($query);
  return $result;
}

function selectAll ($table_name, $order_by = 'id', $order = 'ASC') {
  $query   = selectAllQuery ($table_name, $order_by, $order);
  $results = execSelectAll ($query);
  return $results;
}

function addData ($table_name, $field_data) {
  $query   = addQuery ($table_name, $field_data);
  $result  = execAdd ($query);
  return $result;
}

function editData ($table_name, $field_data, $data_id) {
  $query  = editQuery ($table_name, $field_data, $data_id);
  $result = execEdit ($query);
  return $result;
}

function deleteData ($table_name, $data_id) {
  $query  = deleteQuery ($table_name, $data_id);
  $result = execDelete ($query);
  return $result;
}

// CLEAR

function clearRequest ($data) {
  if(is_array($data)){
    foreach($data as $key => $value){
      if(is_array($value)){$data[$key] = clearRequest ($value);}
      else{$data[$key] = htmlspecialchars($value, ENT_QUOTES, 'UTF-8');}
    }
  }
  else{
    $data = htmlspecialchars($value, ENT_QUOTES, 'UTF-8');
  }
  return $data;
}

// LOG

function logIt ($log_type, $log) {
  global $conf;
  if(!isset($conf['log'][$log_type])){
    $log_type = 'trash';
  }
  $_SESSION[$conf['session_name']]['log'][$log_type][] = $log;
}

function writeLog () {
  global $conf;
  if(isset($_SESSION[$conf['session_name']]['log'])){

    $now          = date("Y-m-d H:i:s");
    if(isset($_SERVER['REMOTE_ADDR'])){
      $remote_ip = $_SERVER['REMOTE_ADDR'];
    }
    else{
      $remote_ip = '0.0.0.0';
    }

    foreach($_SESSION[$conf['session_name']]['log'] as $log_type => $logs){
      if(isset($conf['log'][$log_type])){$log_file = $conf['log'][$log_type];}
      else{$log_file = $conf['log']['trash'];}
      
      if(sizeof($logs) > 0){
        if($handle = fopen($log_file, 'a')){
          foreach($logs as $log){
            $log_line   = $now.' - '.$conf['session_name'].' - '.$remote_ip.' -- '.$log;
            fwrite($handle, $log_line.PHP_EOL);
          }
          fclose($handle);
        }
      }
    }
  }
  $_SESSION[$conf['session_name']]['log'] = array();
}

// DATE

function humanDate ($time, $date_type = 'normal') {
  $human_date = '';
  
  if(empty($time)){return $human_date;}
  
  $month_tab  = array('', 'Jan', 'F&eacute;v', 'Mars', 'Avril', 'Mai', 'Juin', 'Juil', 'Ao&ucirc;', 'Sept', 'Oct', 'Nov', 'D&eacute;c');
  $day_tab    = array('lundi', 'mardi', 'mercredi', 'jeudi', 'vendredi', 'samedi', 'dimanche');
  
  if($date_type == 'normal'){
    $human_date = date("Y-m-d", $time);
  }
  else if($date_type == 'complete'){
    $human_date = $day_tab[date("N", $time)].' '.date("j", $time).' '.$month_tab[date("n", $time)].' '.date("Y", $time).' à '.date("H:i", $time);
  }
  else if($date_type == 'full'){
    $human_date = date("Y-m-d H:i:s", $time);
  }
  
  return $human_date;
}

// MAIL

function mailIt ($mail_dst, $mail_title, $mail_core, $mail_from = 'no_from') {
  global $conf;
  
  if($mail_from == 'no_from'){$mail_from = $conf['mail']['from'];}

  $headers  = 'MIME-Version: 1.0' . "\r\n";
  $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
  $headers .= 'From: '. $mail_from . "\r\n";

  if(filter_var($mail_dst, FILTER_VALIDATE_EMAIL)) {
    $mail = mail($mail_dst, $mail_title, $mail_core, $headers);
    return $mail;
  }
  else{
    return 0;
  }
}

?>
